@@ -42,6 +42,7 @@ class BasketController extends Controller
     public function index(Request $request, BasketContract $basket)
     {
         $basket->items = $this->getProcessedItems($basket);
+
         $basket->action = route('shop.basket.store');
         $basket->editable = true;
 
@@ -52,7 +53,7 @@ class BasketController extends Controller
         // Get a list of countries, with the default on top.
         $countries = Country::whereStatus(1)->get()
             ->sortBy(
-                function($item, $index) {
+                function ($item, $index) {
                     if ($item->code == env('DEFAULT_COUNTRY', 'GB')) {
                         $index = -1;
                     }
@@ -144,9 +145,12 @@ class BasketController extends Controller
                 'variant.product.node',
                 ]
             )->get()->map(
-                function($line) {
+                function ($line) {
                         $line->url = $line->variant->product->getUrl();
-                        $line->price_unit = $line->variant->prices->multiple($line->quantity);
+                        $line->price_unit = $line->variant
+                            ->prices
+                            ->multiple($line->quantity)
+                            ->price;
                         $line->price_total = $line->price_unit * $line->quantity;
                         return $line;
                 }
@@ -165,6 +169,8 @@ class BasketController extends Controller
      */
     public function overview(Request $request, BasketContract $basket)
     {
+        $basket->items = $this->getProcessedItems($basket);
+
         if ($basket->items->isEmpty()) {
             return redirect(route('shop.basket.index'));
         }
@@ -174,7 +180,6 @@ class BasketController extends Controller
 
         // Set default editable state for Vue.s
         $basket->editable = false;
-        $basket->items = $this->getProcessedItems($basket);
 
         if ($request->wantsJson()) {
             return $basket;
